@@ -22,7 +22,6 @@ from typing import (
     Optional,
     Sequence,
     Union,
-    cast,
 )
 from uuid import uuid4
 from logging import warning
@@ -48,7 +47,7 @@ from pytket.passes import (  # type: ignore
     BasePass,
     RebaseProjectQ,
     SequencePass,
-    SynthesiseIBM,
+    SynthesiseTket,
     FullPeepholeOptimise,
     DecomposeBoxes,
     FlattenRegisters,
@@ -144,7 +143,7 @@ class ProjectQBackend(Backend):
                 [
                     DecomposeBoxes(),
                     FlattenRegisters(),
-                    SynthesiseIBM(),
+                    SynthesiseTket(),
                     RebaseProjectQ(),
                 ]
             )
@@ -161,7 +160,7 @@ class ProjectQBackend(Backend):
     def process_circuits(
         self,
         circuits: Sequence[Circuit],
-        n_shots: Optional[Union[int, Sequence[int]]] = None,
+        n_shots: Union[None, int, Sequence[Optional[int]]] = None,
         valid_check: bool = True,
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
@@ -170,13 +169,11 @@ class ProjectQBackend(Backend):
         Supported kwargs: `seed`.
         """
         circuits = list(circuits)
-        if hasattr(n_shots, "__iter__"):
-            n_shots_list = list(cast(Sequence[Optional[int]], n_shots))
-            if len(n_shots_list) != len(circuits):
-                raise ValueError("The length of n_shots and circuits must match")
-        else:
-            # convert n_shots to a list
-            n_shots_list = [cast(Optional[int], n_shots)] * len(circuits)
+        n_shots_list = Backend._get_n_shots_as_list(
+            n_shots,
+            len(circuits),
+            optional=True,
+        )
 
         if valid_check:
             self._check_all_circuits(circuits)
